@@ -4,14 +4,16 @@ Classes and functions that connect the different domain model objects with the a
 and handlers to achieve the program's purpose.
 """
 
-from typing import Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 
 from _io import TextIOWrapper
 
 from autoimport.model import SourceCode
 
 
-def fix_files(files: Tuple[TextIOWrapper]) -> Optional[str]:
+def fix_files(
+    files: Tuple[TextIOWrapper], config: Optional[Dict[str, Any]] = None
+) -> Optional[str]:
     """Fix the python source code of a list of files.
 
     If the input is taken from stdin, it will output the value to stdout.
@@ -24,7 +26,7 @@ def fix_files(files: Tuple[TextIOWrapper]) -> Optional[str]:
     """
     for file_wrapper in files:
         source = file_wrapper.read()
-        fixed_source = fix_code(source)
+        fixed_source = fix_code(source, config)
 
         try:
             # Click testing runner doesn't simulate correctly the reading from stdin
@@ -49,7 +51,7 @@ def fix_files(files: Tuple[TextIOWrapper]) -> Optional[str]:
     return None
 
 
-def fix_code(original_source_code: str) -> str:
+def fix_code(original_source_code: str, config: Optional[Dict[str, Any]] = None) -> str:
     """Fix python source code to correct import statements.
 
     It corrects these errors:
@@ -64,4 +66,4 @@ def fix_code(original_source_code: str) -> str:
     Returns:
         Corrected source code.
     """
-    return SourceCode(original_source_code).fix()
+    return SourceCode(original_source_code, config=config).fix()
